@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filteractionmissingtagdialog.h"
@@ -39,7 +26,7 @@ FilterActionMissingTagDialog::FilterActionMissingTagDialog(
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Tag"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     QLabel *label = new QLabel(i18n("Tag was \"%1\".", argsStr));
     label->setObjectName(QStringLiteral("tagnamelabel"));
@@ -58,7 +45,7 @@ FilterActionMissingTagDialog::FilterActionMissingTagDialog(
     QMap<QUrl, QString>::const_iterator map = tagList.constBegin();
     const QMap<QUrl, QString>::const_iterator mapEnd = tagList.constEnd();
     for (; map != mapEnd; ++map) {
-        QListWidgetItem *item = new QListWidgetItem(map.value());
+        auto *item = new QListWidgetItem(map.value());
         item->setData(UrlData, map.key().toString());
         mTagList->addItem(item);
     }
@@ -70,7 +57,7 @@ FilterActionMissingTagDialog::FilterActionMissingTagDialog(
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    QPushButton *user1Button = new QPushButton(this);
+    auto *user1Button = new QPushButton(this);
     user1Button->setObjectName(QStringLiteral("addtag"));
     user1Button->setText(i18n("Add Tag..."));
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
