@@ -1,24 +1,12 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "filteractionsetidentity.h"
-#include "MessageCore/StringUtil"
+#include <MessageCore/StringUtil>
 
 #include "kernel/mailkernel.h"
 #include "filter/dialog/filteractionmissingidentitydialog.h"
@@ -75,7 +63,7 @@ FilterAction::ReturnCode FilterActionSetIdentity::process(ItemContext &context,
         currentId = hrd->asUnicodeString().trimmed().toUInt();
     }
     if (currentId != mParameter) {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Identity");
+        auto *header = new KMime::Headers::Generic("X-KMail-Identity");
         header->fromUnicodeString(QString::number(mParameter), "utf-8");
         if (applyOnOutbound) {
             msg->from()->fromUnicodeString(ident.fullEmailAddr(), "utf-8");
@@ -102,7 +90,7 @@ SearchRule::RequiredPart FilterActionSetIdentity::requiredPart() const
 
 QWidget *FilterActionSetIdentity::createParamWidget(QWidget *parent) const
 {
-    KIdentityManagement::IdentityCombo *comboBox = new KIdentityManagement::IdentityCombo(KernelIf->identityManager(), parent);
+    auto *comboBox = new KIdentityManagement::IdentityCombo(KernelIf->identityManager(), parent);
     comboBox->setObjectName(QStringLiteral("identitycombobox"));
     comboBox->setCurrentIdentity(mParameter);
 
@@ -120,7 +108,7 @@ void FilterActionSetIdentity::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionSetIdentity::clearParamWidget(QWidget *paramWidget) const
 {
-    KIdentityManagement::IdentityCombo *comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
+    auto *comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentIndex(0);
@@ -128,7 +116,7 @@ void FilterActionSetIdentity::clearParamWidget(QWidget *paramWidget) const
 
 void FilterActionSetIdentity::setParamWidgetValue(QWidget *paramWidget) const
 {
-    KIdentityManagement::IdentityCombo *comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
+    auto *comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentIdentity(mParameter);
