@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -37,14 +25,10 @@ FilterAction *FilterActionSetTransport::newAction()
 
 QWidget *FilterActionSetTransport::createParamWidget(QWidget *parent) const
 {
-    MailTransport::TransportComboBox *transportCombobox = new MailTransport::TransportComboBox(parent);
+    auto *transportCombobox = new MailTransport::TransportComboBox(parent);
     transportCombobox->setObjectName(QStringLiteral("transportcombobox"));
     setParamWidgetValue(transportCombobox);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(transportCombobox, QOverload<int>::of(&MailTransport::TransportComboBox::currentIndexChanged), this, &FilterActionSetTransport::filterActionModified);
-#else
-    connect(transportCombobox, QOverload<int, const QString &>::of(&MailTransport::TransportComboBox::currentIndexChanged), this, &FilterActionSetTransport::filterActionModified);
-#endif
     return transportCombobox;
 }
 
@@ -84,7 +68,7 @@ FilterAction::ReturnCode FilterActionSetTransport::process(ItemContext &context,
     }
 
     const KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
-    KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Transport");
+    auto *header = new KMime::Headers::Generic("X-KMail-Transport");
     header->fromUnicodeString(argsAsString(), "utf-8");
     msg->setHeader(header);
     msg->assemble();
@@ -110,7 +94,7 @@ void FilterActionSetTransport::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionSetTransport::clearParamWidget(QWidget *paramWidget) const
 {
-    MailTransport::TransportComboBox *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
+    auto *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentIndex(0);
@@ -118,7 +102,7 @@ void FilterActionSetTransport::clearParamWidget(QWidget *paramWidget) const
 
 void FilterActionSetTransport::setParamWidgetValue(QWidget *paramWidget) const
 {
-    MailTransport::TransportComboBox *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
+    auto *comboBox = qobject_cast<MailTransport::TransportComboBox *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentTransport(mParameter);
