@@ -1,20 +1,8 @@
 /*
 
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filteractionunsetstatus.h"
@@ -89,11 +77,11 @@ QString FilterActionUnsetStatus::sieveCode() const
 {
     QString flagCode;
     const QString parameter = argsAsString();
-    if (parameter == QLatin1String("R")) {
+    if (parameter == QLatin1Char('R')) {
         flagCode = QStringLiteral("\\\\Seen");
-    } else if (parameter == QLatin1String("D")) {
+    } else if (parameter == QLatin1Char('D')) {
         flagCode = QStringLiteral("\\\\Deleted");
-    } else if (parameter == QLatin1String("A")) {
+    } else if (parameter == QLatin1Char('A')) {
         flagCode = QStringLiteral("\\\\Answered");
     } else {
         qCDebug(MAILCOMMON_LOG) << " FilterActionSetStatus::sieveCode() unknown flags" << parameter;
