@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "filterimportergmail.h"
@@ -27,7 +15,6 @@ using namespace MailCommon;
 
 FilterImporterGmail::FilterImporterGmail(QFile *file)
     : FilterImporterAbstract()
-    , mFilterCount(0)
 {
     QDomDocument doc;
     if (!loadDomElement(doc, file)) {
@@ -65,7 +52,7 @@ QString FilterImporterGmail::createUniqFilterName()
 
 void FilterImporterGmail::parseFilters(const QDomElement &e)
 {
-    MailCommon::MailFilter *filter = new MailCommon::MailFilter();
+    auto *filter = new MailCommon::MailFilter();
     filter->setAutoNaming(true);
     const QString uniqName = createUniqFilterName();
     filter->pattern()->setName(uniqName);
