@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2011 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2011 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "filtermanager.h"
@@ -39,9 +26,7 @@ class Q_DECL_HIDDEN FilterManager::Private
 public:
     Private(FilterManager *qq)
         : q(qq)
-        , mMailFilterAgentInterface(nullptr)
         , mMonitor(new Akonadi::Monitor)
-        , mInitialized(false)
     {
         const auto service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent,
                                                                       QStringLiteral("akonadi_mailfilter_agent"));
@@ -58,10 +43,10 @@ public:
     static FilterManager *mInstance;
     static FilterActionDict *mFilterActionDict;
 
-    FilterManager *q;
+    FilterManager *const q;
     OrgFreedesktopAkonadiMailFilterAgentInterface *mMailFilterAgentInterface = nullptr;
     QVector<MailCommon::MailFilter *> mFilters;
-    Akonadi::Monitor *mMonitor = nullptr;
+    Akonadi::Monitor *const mMonitor;
     bool mInitialized = false;
 };
 
@@ -160,7 +145,7 @@ void FilterManager::slotServerStateChanged(Akonadi::ServerManager::State state)
 
 void FilterManager::updateTagList()
 {
-    Akonadi::TagFetchJob *fetchJob = new Akonadi::TagFetchJob(this);
+    auto *fetchJob = new Akonadi::TagFetchJob(this);
     fetchJob->fetchScope().fetchAttribute<Akonadi::TagAttribute>();
     connect(fetchJob, &Akonadi::TagFetchJob::result, this, &FilterManager::slotFinishedTagListing);
 }
@@ -182,7 +167,7 @@ void FilterManager::slotFinishedTagListing(KJob *job)
     if (job->error()) {
         qCWarning(MAILCOMMON_LOG) << "failed to retrieve tags " << job->errorString();
     }
-    Akonadi::TagFetchJob *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
+    auto *fetchJob = static_cast<Akonadi::TagFetchJob *>(job);
     const Akonadi::Tag::List lstTags = fetchJob->tags();
     for (const Akonadi::Tag &tag : lstTags) {
         d->mTagList.insert(tag.url(), tag.name());
@@ -243,7 +228,7 @@ void FilterManager::filter(const Akonadi::Item &item, FilterSet set, bool accoun
 
 void FilterManager::filter(const Akonadi::Collection &collection, FilterSet set) const
 {
-    filter(Akonadi::Collection::List{ collection }, set);
+    filter(Akonadi::Collection::List { collection }, set);
 }
 
 void FilterManager::filter(const Akonadi::Collection::List &collections, FilterSet set) const
@@ -259,7 +244,7 @@ void FilterManager::filter(const Akonadi::Collection::List &collections, FilterS
 
 void FilterManager::filter(const Akonadi::Collection &collection, const QStringList &listFilters) const
 {
-    filter(Akonadi::Collection::List{ collection }, listFilters);
+    filter(Akonadi::Collection::List { collection }, listFilters);
 }
 
 void FilterManager::filter(const Akonadi::Collection::List &collections, const QStringList &listFilters, FilterSet set) const
