@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "invalidfilterdialog.h"
@@ -31,9 +19,9 @@ using namespace MailCommon;
 InvalidFilterDialog::InvalidFilterDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Invalid Filters"));
+    setWindowTitle(i18nc("@title:window", "Invalid Filters"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -45,7 +33,7 @@ InvalidFilterDialog::InvalidFilterDialog(QWidget *parent)
     okButton->setText(i18n("Discard"));
 
     QWidget *w = new QWidget(this);
-    QVBoxLayout *vbox = new QVBoxLayout;
+    auto *vbox = new QVBoxLayout;
     vbox->setContentsMargins(0, 0, 0, 0);
     w->setLayout(vbox);
     mInvalidFilterWidget = new InvalidFilterWidget(this);
