@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kmfilteraccountlist.h"
@@ -33,8 +21,7 @@ KMFilterAccountList::KMFilterAccountList(QWidget *parent)
     : QTreeWidget(parent)
 {
     setColumnCount(2);
-    QStringList headerNames;
-    headerNames << i18n("Account Name") << i18n("Type");
+    const QStringList headerNames{i18n("Account Name"), i18n("Type")};
     setHeaderItem(new QTreeWidgetItem(headerNames));
     setAllColumnsShowFocus(true);
     setFrameStyle(QFrame::WinPanel + QFrame::Sunken);
@@ -62,7 +49,7 @@ void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
     const int nbAccount = lst.count();
     for (int i = 0; i < nbAccount; ++i) {
         const Akonadi::AgentInstance agent = lst.at(i);
-        QTreeWidgetItem *listItem = new QTreeWidgetItem(this, top);
+        auto *listItem = new QTreeWidgetItem(this, top);
         listItem->setText(0, agent.name());
         listItem->setText(1, agent.type().name());
         listItem->setText(2, agent.identifier());
@@ -111,7 +98,7 @@ void KMFilterAccountList::applyOnAccount(const QStringList &lstAccount)
     const int nbAccount = lst.count();
     for (int i = 0; i < nbAccount; ++i) {
         const Akonadi::AgentInstance agent = lst.at(i);
-        QTreeWidgetItem *listItem = new QTreeWidgetItem(this, top);
+        auto *listItem = new QTreeWidgetItem(this, top);
         listItem->setText(0, agent.name());
         listItem->setText(1, agent.type().name());
         listItem->setText(2, agent.identifier());
