@@ -1,20 +1,8 @@
 /*
 
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "foldertreeview.h"
@@ -116,7 +104,7 @@ void FolderTreeView::readConfig()
 {
     KConfigGroup myGroup(KernelIf->config(), "MainFolderView");
     int iIconSize = myGroup.readEntry("IconSize", iconSize().width());
-    if (iIconSize < 16 || iIconSize > 32) {
+    if ((iIconSize < 16) || (iIconSize > 32)) {
         iIconSize = 22;
     }
     setIconSize(QSize(iIconSize, iIconSize));
@@ -158,7 +146,7 @@ void FolderTreeView::slotHeaderContextMenuRequested(const QPoint &pnt)
 
     static const int icon_sizes[] = { 16, 22, 32};
 
-    QActionGroup *grp = new QActionGroup(&menu);
+    auto *grp = new QActionGroup(&menu);
     for (int i : icon_sizes) {
         act = menu.addAction(QStringLiteral("%1x%2").arg(i).arg(i));
         act->setCheckable(true);
@@ -211,7 +199,7 @@ void FolderTreeView::slotHeaderContextMenuRequested(const QPoint &pnt)
 
 void FolderTreeView::slotHeaderContextMenuChangeSortingPolicy(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto *act = qobject_cast< QAction * >(sender());
     if (!act) {
         return;
     }
@@ -261,7 +249,7 @@ void FolderTreeView::setSortingPolicy(FolderTreeWidget::SortingPolicy policy, bo
 
 void FolderTreeView::slotHeaderContextMenuChangeToolTipDisplayPolicy(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto *act = qobject_cast< QAction * >(sender());
     if (!act) {
         return;
     }
@@ -278,7 +266,7 @@ void FolderTreeView::slotHeaderContextMenuChangeToolTipDisplayPolicy(bool)
 
 void FolderTreeView::slotHeaderContextMenuChangeHeader(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto *act = qobject_cast< QAction * >(sender());
     if (!act) {
         return;
     }
@@ -304,7 +292,7 @@ void FolderTreeView::slotHeaderContextMenuChangeHeader(bool)
 
 void FolderTreeView::slotHeaderContextMenuChangeIconSize(bool)
 {
-    QAction *act = qobject_cast< QAction * >(sender());
+    auto *act = qobject_cast< QAction * >(sender());
     if (!act) {
         return;
     }
@@ -577,7 +565,7 @@ Akonadi::Collection FolderTreeView::currentFolder() const
 
 void FolderTreeView::mousePressEvent(QMouseEvent *e)
 {
-    const bool buttonPressedIsMiddle = (e->button() == Qt::MidButton);
+    const bool buttonPressedIsMiddle = (e->button() == Qt::MiddleButton);
     Q_EMIT newTabRequested(buttonPressedIsMiddle);
     EntityTreeView::mousePressEvent(e);
 }
