@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "foldertreewidgetproxymodel.h"
@@ -26,7 +13,6 @@
 
 #include <AgentInstance>
 #include <AgentManager>
-#include <Collection>
 #include <EntityTreeModel>
 #include <MimeTypeChecker>
 
@@ -57,7 +43,7 @@ public:
                     = q->sourceModel()->data(
                           firstIndex, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
                 if (collectionFirst.isValid() && collectionFirst.hasAttribute<Akonadi::CollectionQuotaAttribute>()) {
-                    const Akonadi::CollectionQuotaAttribute *quota = collectionFirst.attribute<Akonadi::CollectionQuotaAttribute>();
+                    const auto *quota = collectionFirst.attribute<Akonadi::CollectionQuotaAttribute>();
 
                     if (quota->currentValue() > -1 && quota->maximumValue() > 0) {
                         percentage = (100.0 * quota->currentValue()) / quota->maximumValue();
@@ -76,7 +62,7 @@ public:
 
     QColor brokenAccountColor;
     qreal threshold = 0.0;
-    FolderTreeWidgetProxyModel *q;
+    FolderTreeWidgetProxyModel *const q;
     bool enableCheck = false;
     bool hideVirtualFolder = false;
     bool hideSpecificFolder = false;
