@@ -1,20 +1,8 @@
 /*
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mailkernel.h"
@@ -51,7 +39,7 @@ public:
         delete kernel;
     }
 
-    Kernel *kernel;
+    Kernel *const kernel;
 };
 
 Q_GLOBAL_STATIC(KernelPrivate, sInstance)
@@ -190,7 +178,7 @@ void Kernel::initFolders()
     findCreateDefaultCollection(Akonadi::SpecialMailCollections::Trash);
     findCreateDefaultCollection(Akonadi::SpecialMailCollections::Templates);
 
-    Akonadi::SpecialMailCollectionsDiscoveryJob *job
+    auto *job
         = new Akonadi::SpecialMailCollectionsDiscoveryJob(this);
     job->start();
     // we don't connect to the job directly: it will register stuff into SpecialMailCollections, which will Q_EMIT signals.
@@ -206,7 +194,7 @@ void Kernel::findCreateDefaultCollection(Akonadi::SpecialMailCollections::Type t
             emergencyExit(i18n("You do not have read/write permission to your inbox folder."));
         }
     } else {
-        Akonadi::SpecialMailCollectionsRequestJob *job
+        auto *job
             = new Akonadi::SpecialMailCollectionsRequestJob(this);
 
         connect(job, &Akonadi::SpecialMailCollectionsRequestJob::result, this, &Kernel::createDefaultCollectionDone);
@@ -222,7 +210,7 @@ void Kernel::createDefaultCollectionDone(KJob *job)
         return;
     }
 
-    Akonadi::SpecialMailCollectionsRequestJob *requestJob
+    auto *requestJob
         = qobject_cast<Akonadi::SpecialMailCollectionsRequestJob *>(job);
 
     const Akonadi::Collection col = requestJob->collection();
