@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "snippetcustomfileattachmentnamewidget.h"
@@ -30,11 +17,11 @@ using namespace MailCommon;
 SnippetCustomFileAttachmentNameWidget::SnippetCustomFileAttachmentNameWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
-    QHBoxLayout *lineEditLayout = new QHBoxLayout;
+    auto *lineEditLayout = new QHBoxLayout;
     lineEditLayout->setObjectName(QStringLiteral("lineEditLayout"));
     lineEditLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -48,7 +35,7 @@ SnippetCustomFileAttachmentNameWidget::SnippetCustomFileAttachmentNameWidget(QWi
 
     mainLayout->addLayout(lineEditLayout);
 
-    QHBoxLayout *convertMenuLayout = new QHBoxLayout;
+    auto *convertMenuLayout = new QHBoxLayout;
     convertMenuLayout->setObjectName(QStringLiteral("convertMenuLayout"));
     convertMenuLayout->setContentsMargins(0, 0, 0, 0);
     convertMenuLayout->addStretch(1);
