@@ -1,21 +1,7 @@
 /*
-   Copyright (c) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "snippetwidget.h"
@@ -27,7 +13,6 @@
 #include <KLocalizedString>
 #include <QComboBox>
 #include <KLineEdit>
-#include <QAbstractListModel>
 #include <QVBoxLayout>
 using namespace MailCommon;
 
@@ -44,14 +29,14 @@ SnippetWidget::SnippetWidget(QWidget *parent)
     : QWidget(parent)
     , d(new SnippetWidgetPrivate)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setObjectName(QStringLiteral("mainlayout"));
     layout->setContentsMargins(0, 0, 0, 0);
     d->wdg = new QWidget(this);
     d->mUi.setupUi(d->wdg);
     layout->addWidget(d->wdg);
 
-    MessageComposer::ConvertSnippetVariableMenu *variableMenu = new MessageComposer::ConvertSnippetVariableMenu(false, this, this);
+    auto *variableMenu = new MessageComposer::ConvertSnippetVariableMenu(false, this, this);
     d->mUi.pushButtonVariables->setMenu(variableMenu->menu());
     connect(variableMenu, &MessageComposer::ConvertSnippetVariableMenu::insertVariable, this, [this](MessageComposer::ConvertSnippetVariablesUtil::VariableType type) {
         d->mUi.snippetText->editor()->insertPlainText(MessageComposer::ConvertSnippetVariablesUtil::snippetVariableFromEnum(type) + QLatin1Char(' '));
@@ -86,13 +71,13 @@ SnippetWidget::SnippetWidget(QWidget *parent)
     connect(d->mUi.keyWidget, &KKeySequenceWidget::keySequenceChanged, this, [this]() {
         d->wasChanged = true;
     });
-    connect(d->mUi.cc, &QLineEdit::textChanged, this, [this]() {
+    connect(d->mUi.cc, &Akonadi::EmailAddressRequester::textChanged, this, [this]() {
         d->wasChanged = true;
     });
-    connect(d->mUi.to, &QLineEdit::textChanged, this, [this]() {
+    connect(d->mUi.to, &Akonadi::EmailAddressRequester::textChanged, this, [this]() {
         d->wasChanged = true;
     });
-    connect(d->mUi.bcc, &QLineEdit::textChanged, this, [this]() {
+    connect(d->mUi.bcc, &Akonadi::EmailAddressRequester::textChanged, this, [this]() {
         d->wasChanged = true;
     });
     connect(d->mUi.subject, &QLineEdit::textChanged, this, [this]() {
