@@ -1,21 +1,7 @@
-/* Copyright 2010 Thomas McGuire <mcguire@kde.org>
-   Copyright 2012-2019 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2010 Thomas McGuire <mcguire@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #include "tag.h"
 
@@ -50,7 +36,7 @@ Tag::Ptr Tag::fromAkonadi(const Akonadi::Tag &akonadiTag)
     tag->iconName = QStringLiteral("mail-tagged");
     tag->inToolbar = false;
     tag->isImmutable = akonadiTag.isImmutable();
-    const Akonadi::TagAttribute *attr = akonadiTag.attribute<Akonadi::TagAttribute>();
+    const auto *attr = akonadiTag.attribute<Akonadi::TagAttribute>();
     if (attr) {
         if (!attr->iconName().isEmpty()) {
             tag->iconName = attr->iconName();
@@ -81,7 +67,7 @@ Akonadi::Tag Tag::saveToAkonadi(Tag::SaveFlags saveFlags) const
     } else {
         tag.setType(Akonadi::Tag::GENERIC);
     }
-    Akonadi::TagAttribute *attr = tag.attribute<Akonadi::TagAttribute>(Akonadi::Tag::AddIfMissing);
+    auto *attr = tag.attribute<Akonadi::TagAttribute>(Akonadi::Tag::AddIfMissing);
     attr->setDisplayName(tagName);
     attr->setIconName(iconName);
     attr->setInToolbar(inToolbar);
